![](header.png)

# Welcome
*Litemark* is a lightweight *Markdown* dialect originally created to be the markup language for the *Codegame Platform* project.
You are reading the Litemark demo written in Litemark in a file named _litemark-demo.md_ and rendered with Litemark Viewer (Press *F5* to refresh).

## Quick Overview
This is the [link](https://github.com/pyrustic/litemark) to the *GitHub* repository of this project. To check the full URL of the link, just hover over it. Right click on the link to copy it.

You can also reference a specific @[heading](#_Welcome) in the current document or in another Litemark document, thanks to the *inlink* feature.

Make your text _italic_, *bold* or ~overstrike~ it.

!Warning: yes, with Litemark you can grab the reader's attention when needed \!!

You can insert images in your Litemark document (see the beautiful header of this demo).

And here is an example of codeblock (right-click on its content to copy it):

```python
def welcome():
    print("Hello friend !")
```

Litemark is not a toy project, nor yet another Markdown dialect. The raison d'être of Litemark is the *Codegame Platform* project.

Visit the [Codegame Platform](https://github.com/pyrustic/codegame) project !
